LocalStack CFn resource providers
===============================

All the Python boilerplate you need to create a distributable python application.


## Quickstart

to install the python and other developer requirements into a venv run:

    make install

## Format code

We use black and isort as code style tools.
To execute them, run:

    make format

## Build distribution

To build a wheel and source distribution, simply run

    make dist
